Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the kube-egress-gateway v1alpha1 API group +kubebuilder:object:generate=true +groupName=egressgateway.kubernetes.azure.com
Index ¶
- Variables
- type GatewayLBConfiguration
- type GatewayLBConfigurationList
- type GatewayLBConfigurationSpec
- type GatewayLBConfigurationStatus
- type GatewayNamespace
- type GatewayStatus
- type GatewayStatusList
- type GatewayStatusSpec
- type GatewayStatusStatus
- type GatewayVMConfiguration
- type GatewayVMConfigurationList
- type GatewayVMConfigurationSpec
- type GatewayVMConfigurationStatus
- type GatewayVmssProfile
- type GatewayWireguardProfile
- type PeerConfiguration
- type PodWireguardEndpoint
- type PodWireguardEndpointList
- type PodWireguardEndpointSpec
- type PodWireguardEndpointStatus
- type RouteType
- type StaticGatewayConfiguration
- type StaticGatewayConfigurationList
- type StaticGatewayConfigurationSpec
- type StaticGatewayConfigurationStatus
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "egressgateway.kubernetes.azure.com", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type GatewayLBConfiguration ¶
type GatewayLBConfiguration struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec GatewayLBConfigurationSpec `json:"spec,omitempty"`
Status *GatewayLBConfigurationStatus `json:"status,omitempty"`
}
GatewayLBConfiguration is the Schema for the gatewaylbconfigurations API
func (*GatewayLBConfiguration) DeepCopy ¶
func (in *GatewayLBConfiguration) DeepCopy() *GatewayLBConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayLBConfiguration.
func (*GatewayLBConfiguration) DeepCopyInto ¶
func (in *GatewayLBConfiguration) DeepCopyInto(out *GatewayLBConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GatewayLBConfiguration) DeepCopyObject ¶
func (in *GatewayLBConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GatewayLBConfigurationList ¶
type GatewayLBConfigurationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []GatewayLBConfiguration `json:"items"`
}
GatewayLBConfigurationList contains a list of GatewayLBConfiguration
func (*GatewayLBConfigurationList) DeepCopy ¶
func (in *GatewayLBConfigurationList) DeepCopy() *GatewayLBConfigurationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayLBConfigurationList.
func (*GatewayLBConfigurationList) DeepCopyInto ¶
func (in *GatewayLBConfigurationList) DeepCopyInto(out *GatewayLBConfigurationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GatewayLBConfigurationList) DeepCopyObject ¶
func (in *GatewayLBConfigurationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GatewayLBConfigurationSpec ¶
type GatewayLBConfigurationSpec struct {
// Name of the gateway nodepool to apply the gateway configuration.
// +optional
GatewayNodepoolName string `json:"gatewayNodepoolName,omitempty"`
// Profile of the gateway VMSS to apply the gateway configuration.
// +optional
GatewayVmssProfile `json:"gatewayVmssProfile,omitempty"`
// Whether to provision public IP prefixes for outbound.
//+kubebuilder:default=true
ProvisionPublicIps bool `json:"provisionPublicIps"`
// BYO Resource ID of public IP prefix to be used as outbound.
// +optional
PublicIpPrefixId string `json:"publicIpPrefixId,omitempty"`
}
GatewayLBConfigurationSpec defines the desired state of GatewayLBConfiguration
func (*GatewayLBConfigurationSpec) DeepCopy ¶
func (in *GatewayLBConfigurationSpec) DeepCopy() *GatewayLBConfigurationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayLBConfigurationSpec.
func (*GatewayLBConfigurationSpec) DeepCopyInto ¶
func (in *GatewayLBConfigurationSpec) DeepCopyInto(out *GatewayLBConfigurationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GatewayLBConfigurationStatus ¶
type GatewayLBConfigurationStatus struct {
// Gateway IP for wireguard connection.
FrontendIp string `json:"frontendIp,omitempty"`
// Listening port of the gateway side wireguard daemon.
ServerPort int32 `json:"serverPort,omitempty"`
// Egress IP Prefix CIDR used for this gateway configuration.
EgressIpPrefix string `json:"egressIpPrefix,omitempty"`
}
GatewayLBConfigurationStatus defines the observed state of GatewayLBConfiguration
func (*GatewayLBConfigurationStatus) DeepCopy ¶
func (in *GatewayLBConfigurationStatus) DeepCopy() *GatewayLBConfigurationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayLBConfigurationStatus.
func (*GatewayLBConfigurationStatus) DeepCopyInto ¶
func (in *GatewayLBConfigurationStatus) DeepCopyInto(out *GatewayLBConfigurationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GatewayNamespace ¶
type GatewayNamespace struct {
// StaticGatewayConfiguration in <namespace>/<name> pattern
StaticGatewayConfiguration string `json:"staticGatewayConfiguration,omitempty"`
// Network namespace name
NetnsName string `json:"netnsName,omitempty"`
}
func (*GatewayNamespace) DeepCopy ¶
func (in *GatewayNamespace) DeepCopy() *GatewayNamespace
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayNamespace.
func (*GatewayNamespace) DeepCopyInto ¶
func (in *GatewayNamespace) DeepCopyInto(out *GatewayNamespace)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GatewayStatus ¶
type GatewayStatus struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec GatewayStatusSpec `json:"spec,omitempty"`
Status GatewayStatusStatus `json:"status,omitempty"`
}
GatewayStatus is the Schema for the gatewaystatuses API
func (*GatewayStatus) DeepCopy ¶
func (in *GatewayStatus) DeepCopy() *GatewayStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayStatus.
func (*GatewayStatus) DeepCopyInto ¶
func (in *GatewayStatus) DeepCopyInto(out *GatewayStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GatewayStatus) DeepCopyObject ¶
func (in *GatewayStatus) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GatewayStatusList ¶
type GatewayStatusList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []GatewayStatus `json:"items"`
}
GatewayStatusList contains a list of GatewayStatus
func (*GatewayStatusList) DeepCopy ¶
func (in *GatewayStatusList) DeepCopy() *GatewayStatusList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayStatusList.
func (*GatewayStatusList) DeepCopyInto ¶
func (in *GatewayStatusList) DeepCopyInto(out *GatewayStatusList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GatewayStatusList) DeepCopyObject ¶
func (in *GatewayStatusList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GatewayStatusSpec ¶
type GatewayStatusSpec struct {
// List of ready gateway namespaces
ReadyGatewayNamespaces []GatewayNamespace `json:"readyGatewayNamespaces,omitempty"`
// List of ready peer configurations
ReadyPeerConfigurations []PeerConfiguration `json:"readyPeerConfigurations,omitempty"`
}
GatewayStatusSpec defines the desired state of GatewayStatus
func (*GatewayStatusSpec) DeepCopy ¶
func (in *GatewayStatusSpec) DeepCopy() *GatewayStatusSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayStatusSpec.
func (*GatewayStatusSpec) DeepCopyInto ¶
func (in *GatewayStatusSpec) DeepCopyInto(out *GatewayStatusSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GatewayStatusStatus ¶
type GatewayStatusStatus struct {
}
GatewayStatusStatus defines the observed state of GatewayStatus
func (*GatewayStatusStatus) DeepCopy ¶
func (in *GatewayStatusStatus) DeepCopy() *GatewayStatusStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayStatusStatus.
func (*GatewayStatusStatus) DeepCopyInto ¶
func (in *GatewayStatusStatus) DeepCopyInto(out *GatewayStatusStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GatewayVMConfiguration ¶
type GatewayVMConfiguration struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec GatewayVMConfigurationSpec `json:"spec,omitempty"`
Status *GatewayVMConfigurationStatus `json:"status,omitempty"`
}
GatewayVMConfiguration is the Schema for the gatewayvmconfigurations API
func (*GatewayVMConfiguration) DeepCopy ¶
func (in *GatewayVMConfiguration) DeepCopy() *GatewayVMConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayVMConfiguration.
func (*GatewayVMConfiguration) DeepCopyInto ¶
func (in *GatewayVMConfiguration) DeepCopyInto(out *GatewayVMConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GatewayVMConfiguration) DeepCopyObject ¶
func (in *GatewayVMConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GatewayVMConfigurationList ¶
type GatewayVMConfigurationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []GatewayVMConfiguration `json:"items"`
}
GatewayVMConfigurationList contains a list of GatewayVMConfiguration
func (*GatewayVMConfigurationList) DeepCopy ¶
func (in *GatewayVMConfigurationList) DeepCopy() *GatewayVMConfigurationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayVMConfigurationList.
func (*GatewayVMConfigurationList) DeepCopyInto ¶
func (in *GatewayVMConfigurationList) DeepCopyInto(out *GatewayVMConfigurationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GatewayVMConfigurationList) DeepCopyObject ¶
func (in *GatewayVMConfigurationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GatewayVMConfigurationSpec ¶
type GatewayVMConfigurationSpec struct {
// Name of the gateway nodepool to apply the gateway configuration.
// +optional
GatewayNodepoolName string `json:"gatewayNodepoolName,omitempty"`
// Profile of the gateway VMSS to apply the gateway configuration.
// +optional
GatewayVmssProfile `json:"gatewayVmssProfile,omitempty"`
// Whether to provision public IP prefixes for outbound.
//+kubebuilder:default=true
ProvisionPublicIps bool `json:"provisionPublicIps"`
// BYO Resource ID of public IP prefix to be used as outbound.
// +optional
PublicIpPrefixId string `json:"publicIpPrefixId,omitempty"`
}
GatewayVMConfigurationSpec defines the desired state of GatewayVMConfiguration
func (*GatewayVMConfigurationSpec) DeepCopy ¶
func (in *GatewayVMConfigurationSpec) DeepCopy() *GatewayVMConfigurationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayVMConfigurationSpec.
func (*GatewayVMConfigurationSpec) DeepCopyInto ¶
func (in *GatewayVMConfigurationSpec) DeepCopyInto(out *GatewayVMConfigurationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GatewayVMConfigurationStatus ¶
type GatewayVMConfigurationStatus struct {
// The egress source IP for traffic using this configuration.
EgressIpPrefix string `json:"egressIpPrefix,omitempty"`
}
GatewayVMConfigurationStatus defines the observed state of GatewayVMConfiguration
func (*GatewayVMConfigurationStatus) DeepCopy ¶
func (in *GatewayVMConfigurationStatus) DeepCopy() *GatewayVMConfigurationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayVMConfigurationStatus.
func (*GatewayVMConfigurationStatus) DeepCopyInto ¶
func (in *GatewayVMConfigurationStatus) DeepCopyInto(out *GatewayVMConfigurationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GatewayVmssProfile ¶
type GatewayVmssProfile struct {
// Resource group of the VMSS. Must be in the same subscription.
VmssResourceGroup string `json:"vmssResourceGroup,omitempty"`
// Name of the VMSS
VmssName string `json:"vmssName,omitempty"`
// Public IP prefix size to be applied to this VMSS.
//+kubebuilder:validation:Minimum=0
//+kubebuilder:validation:Maximum=31
PublicIpPrefixSize int32 `json:"publicIpPrefixSize,omitempty"`
}
GatewayVmssProfile finds an existing gateway VMSS (virtual machine scale set).
func (*GatewayVmssProfile) DeepCopy ¶
func (in *GatewayVmssProfile) DeepCopy() *GatewayVmssProfile
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayVmssProfile.
func (*GatewayVmssProfile) DeepCopyInto ¶
func (in *GatewayVmssProfile) DeepCopyInto(out *GatewayVmssProfile)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GatewayWireguardProfile ¶
type GatewayWireguardProfile struct {
// Gateway IP for wireguard connection.
WireguardServerIp string `json:"wireguardServerIp,omitempty"`
// Listening port of the gateway side wireguard daemon.
WireguardServerPort int32 `json:"wireguardServerPort,omitempty"`
// Gateway side wireguard public key.
WireguardPublicKey string `json:"wireguardPublicKey,omitempty"`
// Reference of the secret that holds gateway side wireguard private key.
WireguardPrivateKeySecretRef *corev1.ObjectReference `json:"wireguardPrivateKeySecretRef,omitempty"`
}
GatewayWireguardProfile provides details about gateway side wireguard configuration.
func (*GatewayWireguardProfile) DeepCopy ¶
func (in *GatewayWireguardProfile) DeepCopy() *GatewayWireguardProfile
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GatewayWireguardProfile.
func (*GatewayWireguardProfile) DeepCopyInto ¶
func (in *GatewayWireguardProfile) DeepCopyInto(out *GatewayWireguardProfile)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PeerConfiguration ¶
type PeerConfiguration struct {
// PodWireguardEndpoint in <namespace>/<name> pattern
PodWireguardEndpoint string `json:"podWireguardEndpoint,omitempty"`
// Network namespace name
NetnsName string `json:"netnsName,omitempty"`
// Public Key
PublicKey string `json:"publicKey,omitempty"`
}
func (*PeerConfiguration) DeepCopy ¶
func (in *PeerConfiguration) DeepCopy() *PeerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PeerConfiguration.
func (*PeerConfiguration) DeepCopyInto ¶
func (in *PeerConfiguration) DeepCopyInto(out *PeerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PodWireguardEndpoint ¶
type PodWireguardEndpoint struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PodWireguardEndpointSpec `json:"spec,omitempty"`
Status PodWireguardEndpointStatus `json:"status,omitempty"`
}
PodWireguardEndpoint is the Schema for the podwireguardendpoints API
func (*PodWireguardEndpoint) DeepCopy ¶
func (in *PodWireguardEndpoint) DeepCopy() *PodWireguardEndpoint
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodWireguardEndpoint.
func (*PodWireguardEndpoint) DeepCopyInto ¶
func (in *PodWireguardEndpoint) DeepCopyInto(out *PodWireguardEndpoint)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PodWireguardEndpoint) DeepCopyObject ¶
func (in *PodWireguardEndpoint) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PodWireguardEndpointList ¶
type PodWireguardEndpointList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []PodWireguardEndpoint `json:"items"`
}
PodWireguardEndpointList contains a list of PodWireguardEndpoint
func (*PodWireguardEndpointList) DeepCopy ¶
func (in *PodWireguardEndpointList) DeepCopy() *PodWireguardEndpointList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodWireguardEndpointList.
func (*PodWireguardEndpointList) DeepCopyInto ¶
func (in *PodWireguardEndpointList) DeepCopyInto(out *PodWireguardEndpointList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PodWireguardEndpointList) DeepCopyObject ¶
func (in *PodWireguardEndpointList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PodWireguardEndpointSpec ¶
type PodWireguardEndpointSpec struct {
// Name of StaticGatewayConfiguration the pod uses.
StaticGatewayConfiguration string `json:"staticGatewayConfiguration,omitempty"`
// IPv4 address assigned to the pod.
PodIpAddress string `json:"podIpAddress,omitempty"`
// wireguard public key on pod side.
PodWireguardPublicKey string `json:"podWireguardPublicKey,omitempty"`
}
PodWireguardEndpointSpec defines the desired state of PodWireguardEndpoint
func (*PodWireguardEndpointSpec) DeepCopy ¶
func (in *PodWireguardEndpointSpec) DeepCopy() *PodWireguardEndpointSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodWireguardEndpointSpec.
func (*PodWireguardEndpointSpec) DeepCopyInto ¶
func (in *PodWireguardEndpointSpec) DeepCopyInto(out *PodWireguardEndpointSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PodWireguardEndpointStatus ¶
type PodWireguardEndpointStatus struct {
}
PodWireguardEndpointStatus defines the observed state of PodWireguardEndpoint
func (*PodWireguardEndpointStatus) DeepCopy ¶
func (in *PodWireguardEndpointStatus) DeepCopy() *PodWireguardEndpointStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodWireguardEndpointStatus.
func (*PodWireguardEndpointStatus) DeepCopyInto ¶
func (in *PodWireguardEndpointStatus) DeepCopyInto(out *PodWireguardEndpointStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RouteType ¶
type RouteType string
RouteType defines the type of defaultRoute. +kubebuilder:validation:Enum=azureNetworking;staticEgressGateway
type StaticGatewayConfiguration ¶
type StaticGatewayConfiguration struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec StaticGatewayConfigurationSpec `json:"spec,omitempty"`
Status StaticGatewayConfigurationStatus `json:"status,omitempty"`
}
StaticGatewayConfiguration is the Schema for the staticgatewayconfigurations API
func (*StaticGatewayConfiguration) DeepCopy ¶
func (in *StaticGatewayConfiguration) DeepCopy() *StaticGatewayConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StaticGatewayConfiguration.
func (*StaticGatewayConfiguration) DeepCopyInto ¶
func (in *StaticGatewayConfiguration) DeepCopyInto(out *StaticGatewayConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*StaticGatewayConfiguration) DeepCopyObject ¶
func (in *StaticGatewayConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type StaticGatewayConfigurationList ¶
type StaticGatewayConfigurationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []StaticGatewayConfiguration `json:"items"`
}
StaticGatewayConfigurationList contains a list of StaticGatewayConfiguration
func (*StaticGatewayConfigurationList) DeepCopy ¶
func (in *StaticGatewayConfigurationList) DeepCopy() *StaticGatewayConfigurationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StaticGatewayConfigurationList.
func (*StaticGatewayConfigurationList) DeepCopyInto ¶
func (in *StaticGatewayConfigurationList) DeepCopyInto(out *StaticGatewayConfigurationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*StaticGatewayConfigurationList) DeepCopyObject ¶
func (in *StaticGatewayConfigurationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type StaticGatewayConfigurationSpec ¶
type StaticGatewayConfigurationSpec struct {
// Name of the gateway nodepool to apply the gateway configuration.
// +optional
GatewayNodepoolName string `json:"gatewayNodepoolName,omitempty"`
// Profile of the gateway VMSS to apply the gateway configuration.
// +optional
GatewayVmssProfile `json:"gatewayVmssProfile,omitempty"`
// Pod default route, should be either azureNetworking (pod's eth0) or staticEgressGateway (default).
//+kubebuilder:default=staticEgressGateway
DefaultRoute RouteType `json:"defaultRoute,omitempty"`
// Whether to provision public IP prefixes for outbound.
//+kubebuilder:default=true
ProvisionPublicIps bool `json:"provisionPublicIps"`
// BYO Resource ID of public IP prefix to be used as outbound. This can only be specified when provisionPublicIps is true.
// +optional
PublicIpPrefixId string `json:"publicIpPrefixId,omitempty"`
// CIDRs to be excluded from the default route.
ExcludeCidrs []string `json:"excludeCidrs,omitempty"`
}
StaticGatewayConfigurationSpec defines the desired state of StaticGatewayConfiguration
func (*StaticGatewayConfigurationSpec) DeepCopy ¶
func (in *StaticGatewayConfigurationSpec) DeepCopy() *StaticGatewayConfigurationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StaticGatewayConfigurationSpec.
func (*StaticGatewayConfigurationSpec) DeepCopyInto ¶
func (in *StaticGatewayConfigurationSpec) DeepCopyInto(out *StaticGatewayConfigurationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type StaticGatewayConfigurationStatus ¶
type StaticGatewayConfigurationStatus struct {
// Egress IP Prefix CIDR used for this gateway configuration.
EgressIpPrefix string `json:"egressIpPrefix,omitempty"`
// Gateway side wireguard profile.
GatewayWireguardProfile `json:"gatewayWireguardProfile,omitempty"`
}
StaticGatewayConfigurationStatus defines the observed state of StaticGatewayConfiguration
func (*StaticGatewayConfigurationStatus) DeepCopy ¶
func (in *StaticGatewayConfigurationStatus) DeepCopy() *StaticGatewayConfigurationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StaticGatewayConfigurationStatus.
func (*StaticGatewayConfigurationStatus) DeepCopyInto ¶
func (in *StaticGatewayConfigurationStatus) DeepCopyInto(out *StaticGatewayConfigurationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.